"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deleteImage = exports.getTokenData = exports.getTokenSettings = exports.updateProduct = exports.saveMetaData = exports.generateMultiplyImagesTags = exports.generateTags = exports.searchFiles = exports.getListFiles = exports.uploadFiles = exports.sendAll = exports.send = exports.getSecretHeaderName = exports.getBaseUrl = exports.getBaseAPI = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _filesUpload = require("../utils/files-upload");

var _config = require("../config");

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var getBaseAPI = function getBaseAPI(baseAPI, container, platform) {
  return baseAPI ? baseAPI + '/' : getBaseUrl(container, platform);
};

exports.getBaseAPI = getBaseAPI;

var getBaseUrl = function getBaseUrl(container) {
  var platform = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'filerobot';
  return platform === 'filerobot' ? "https://api.filerobot.com/".concat(container, "/v3/") : "https://".concat(container, ".api.airstore.io/v1/");
};

exports.getBaseUrl = getBaseUrl;

var getSecretHeaderName = function getSecretHeaderName() {
  var platform = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'filerobot';
  return platform === 'filerobot' ? "X-Filerobot-Key" : "X-Airstore-Secret-Key";
};

exports.getSecretHeaderName = getSecretHeaderName;

var send = function send(url) {
  var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'GET';
  var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var headers = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var responseType = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : "json";
  var restOptions = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {};
  return (0, _axios.default)(_objectSpread({
    url: url,
    method: method,
    data: data,
    responseType: responseType,
    headers: headers
  }, restOptions || {})).then(function (_ref) {
    var _ref$data = _ref.data,
        data = _ref$data === void 0 ? {} : _ref$data;
    return data;
  });
};

exports.send = send;

var sendAll = function sendAll(requests) {
  return _axios.default.all(requests).then(_axios.default.spread(function () {
    for (var _len = arguments.length, responses = new Array(_len), _key = 0; _key < _len; _key++) {
      responses[_key] = arguments[_key];
    }

    return responses;
  }));
};
/**
 * Send files to airstore storage.
 * We can send 2 types of files:
 *  - files from <input type="file"/>
 *  - files from urls
 * Method understand what files we give via "data_type" attribute.
 *
 * @param props.uploadPath    {string}  Airstore upload url (like: "//jolipage001.api.airstore.io/upload") or custom
 *   handler
 * @param props.uploadParams  {object}  Params which we need to send to uploadPath
 * @param props.files         {array}   Array with files
 * @param props.uploadKey     {string}  = secret key
 * @param props.data_type     {string}  Available values: "files[]", "files_url[]" (or another if you use custom
 *   handler
 *   uploadPath)
 * @param props.dir     {string}  = directory to upload files
 * @param props.showAlert     {function}  = show alert
 * @returns {Promise}
 */


exports.sendAll = sendAll;

var uploadFiles = function uploadFiles(props) {
  var _props$files = props.files,
      files = _props$files === void 0 ? [] : _props$files,
      _props$config = props.config;
  _props$config = _props$config === void 0 ? {} : _props$config;
  var platform = _props$config.platform,
      _props$config$uploadP = _props$config.uploadPath,
      uploadPath = _props$config$uploadP === void 0 ? '' : _props$config$uploadP,
      _props$config$uploadP2 = _props$config.uploadParams,
      uploadParams = _props$config$uploadP2 === void 0 ? {} : _props$config$uploadP2,
      _props$config$uploadK = _props$config.uploadKey,
      uploadKey = _props$config$uploadK === void 0 ? '' : _props$config$uploadK,
      onUploadProgress = _props$config.onUploadProgress,
      _props$data_type = props.data_type,
      data_type = _props$data_type === void 0 ? 'files[]' : _props$data_type,
      dir = props.dir,
      showAlert = props.showAlert;
  var url = uploadPath || ''; // use independent protocol

  var jsonData = {
    files_urls: []
  };
  var isJson = data_type === 'application/json';

  var defaultHeaders = _defineProperty({}, getSecretHeaderName(platform), uploadKey);

  uploadParams = _objectSpread(_objectSpread({}, uploadParams), {
    dir: dir || uploadParams.dir
  }); // generate params string

  var paramsStr = Object.keys(uploadParams).filter(function (paramName) {
    return uploadParams[paramName] !== null;
  }) // do not use params with NULL value
  .map(function (paramName) {
    return "".concat(paramName, "=").concat(uploadParams[paramName]);
  }).join('&');
  if (paramsStr) url += "?".concat(paramsStr);

  function handleError(error) {
    var data = error.response && error.response.data || {};
    var msg = data.msg && (data.msg.join ? data.msg.join(', ') : data.msg);
    showAlert(msg || error.msg || error.message, data.hint || '', 'error', 8000);
    return error;
  }

  if (files && isJson) {
    _toConsumableArray(files).forEach(function (file) {
      jsonData.files_urls.push(file);
    });

    return new Promise(function (resolve, reject) {
      send(url, 'POST', jsonData, _objectSpread(_objectSpread({}, defaultHeaders), {}, {
        'Content-Type': 'application/json'
      }), 'json', {
        onUploadProgress: onUploadProgress
      }).then(function (response) {
        var _response$status = response.status,
            status = _response$status === void 0 ? 'success' : _response$status,
            _response$files = response.files,
            files = _response$files === void 0 ? [] : _response$files,
            file = response.file,
            _response$upload = response.upload,
            upload = _response$upload === void 0 ? {} : _response$upload;
        var isDuplicate = upload.state === _config.DUPLICATE_CODE;
        var isReplacingData = upload.state === _config.REPLACING_DATA_CODE;

        if (status === 'success' && file) {
          resolve([[file], isDuplicate, isReplacingData]);
        } else if (status === 'success' && files) {
          resolve([files, isDuplicate, isReplacingData]);
        } else if (status === 'error') {
          throw new Error(response.msg + ' ' + response.hint);
        } else reject(response);
      }).catch(function (error) {
        handleError(error);
        reject(error);
      });
    });
  }

  var ajaxData = new FormData();

  _toConsumableArray(files || []).forEach(function (file) {
    return ajaxData.append(data_type, file, file.name || null);
  });

  return (0, _filesUpload.uploadFormDataFiles)(ajaxData, url, onUploadProgress, {
    headers: _objectSpread({}, defaultHeaders)
  }).then(function (responses) {
    var uploadedFiles = [];
    var isDuplicate = false;
    var isReplacingData = false;
    responses.forEach(function (response) {
      if (response) {
        if (response.file) {
          uploadedFiles.push(response.file);
        } else if (response.files) {
          uploadedFiles = [].concat(_toConsumableArray(uploadedFiles), _toConsumableArray(response.files));
        }

        if (response.upload && response.upload.state) {
          if (response.upload.state === _config.DUPLICATE_CODE) {
            isDuplicate = true;
          }

          if (response.upload.state === _config.REPLACING_DATA_CODE) {
            isReplacingData = true;
          }
        }
      }
    });
    return [uploadedFiles, isDuplicate, isReplacingData];
  }).catch(handleError);
};

exports.uploadFiles = uploadFiles;

var getListFiles = function getListFiles(_ref2) {
  var _ref2$dir = _ref2.dir,
      dir = _ref2$dir === void 0 ? '' : _ref2$dir,
      _ref2$container = _ref2.container,
      container = _ref2$container === void 0 ? '' : _ref2$container,
      baseAPI = _ref2.baseAPI,
      platform = _ref2.platform,
      offset = _ref2.offset,
      uploadKey = _ref2.uploadKey,
      sortParams = _ref2.sortParams;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var apiPath = 'list?';
  var directoryPath = dir ? 'dir=' + dir : '';
  var offsetQuery = "&offset=".concat(offset);
  var limit = "&limit=".concat(_config.GALLERY_IMAGES_LIMIT);
  var sort = "&sort=".concat(sortParams.field, ":").concat(sortParams.isUp ? 'asc' : 'desc');
  var url = [baseUrl, apiPath, directoryPath, offsetQuery, limit, sort].join('');
  return send(url, 'GET', null, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return [response.files, response.directories, response.info && response.info.total_files_count];
  });
};

exports.getListFiles = getListFiles;

var searchFiles = function searchFiles(_ref3) {
  var _ref3$query = _ref3.query,
      query = _ref3$query === void 0 ? '' : _ref3$query,
      _ref3$container = _ref3.container,
      container = _ref3$container === void 0 ? '' : _ref3$container,
      platform = _ref3.platform,
      baseAPI = _ref3.baseAPI,
      _ref3$language = _ref3.language,
      language = _ref3$language === void 0 ? 'en' : _ref3$language,
      _ref3$offset = _ref3.offset,
      offset = _ref3$offset === void 0 ? 0 : _ref3$offset,
      uploadKey = _ref3.uploadKey;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var apiPath = 'search?';
  var searchQuery = "q=".concat(query);
  var offsetQuery = "&offset=".concat(offset);
  var url = [baseUrl, apiPath, searchQuery, offsetQuery].join('');
  return send(url, 'GET', null, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return [response.files, response.info && response.info.total_files_count];
  });
};

exports.searchFiles = searchFiles;

var generateTags = function generateTags() {
  var uuid = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var autoTaggingProps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var language = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'en';
  var container = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  var baseAPI = arguments.length > 4 ? arguments[4] : undefined;
  var platform = arguments.length > 5 ? arguments[5] : undefined;
  var uploadKey = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : '';
  var cloudimageToken = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : 'demo';
  var _autoTaggingProps$pro = autoTaggingProps.provider,
      provider = _autoTaggingProps$pro === void 0 ? 'google' : _autoTaggingProps$pro,
      _autoTaggingProps$con = autoTaggingProps.confidence,
      confidence = _autoTaggingProps$con === void 0 ? 60 : _autoTaggingProps$con,
      _autoTaggingProps$lim = autoTaggingProps.limit,
      limit = _autoTaggingProps$lim === void 0 ? 10 : _autoTaggingProps$lim;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var base = "".concat(baseUrl, "process/autotag");
  return send("".concat(base), 'POST', {
    file: {
      uuid: uuid
    },
    meta: {
      languages: [language],
      provider: provider,
      limit: limit,
      confidence: confidence
    }
  }, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.generateTags = generateTags;

var generateMultiplyImagesTags = function generateMultiplyImagesTags() {
  var uuids = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var autoTaggingProps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var language = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'en';
  var container = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
  var baseAPI = arguments.length > 4 ? arguments[4] : undefined;
  var platform = arguments.length > 5 ? arguments[5] : undefined;
  var uploadKey = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : '';
  var _autoTaggingProps$pro2 = autoTaggingProps.provider,
      provider = _autoTaggingProps$pro2 === void 0 ? 'google' : _autoTaggingProps$pro2,
      _autoTaggingProps$con2 = autoTaggingProps.confidence,
      confidence = _autoTaggingProps$con2 === void 0 ? 60 : _autoTaggingProps$con2,
      _autoTaggingProps$lim2 = autoTaggingProps.limit,
      limit = _autoTaggingProps$lim2 === void 0 ? 10 : _autoTaggingProps$lim2;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var base = "".concat(baseUrl, "process/autotag");
  return sendAll(uuids.map(function (uuid) {
    return send("".concat(base), 'POST', {
      file: {
        uuid: uuid
      },
      meta: {
        languages: [language],
        provider: provider,
        limit: limit,
        confidence: confidence
      }
    }, _defineProperty({}, getSecretHeaderName(platform), uploadKey));
  })).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.generateMultiplyImagesTags = generateMultiplyImagesTags;

var saveMetaData = function saveMetaData(_ref4) {
  var files = _ref4.files,
      properties = _ref4.properties,
      config = _ref4.config,
      _ref4$personalTags = _ref4.personalTags,
      personalTags = _ref4$personalTags === void 0 ? [] : _ref4$personalTags,
      _ref4$tokenMetadata = _ref4.tokenMetadata,
      tokenMetadata = _ref4$tokenMetadata === void 0 ? {} : _ref4$tokenMetadata;
  var container = config.container,
      baseAPI = config.baseAPI,
      platform = config.platform,
      uploadKey = config.uploadKey;
  var isEDGYMetadataVersion = tokenMetadata.isEDGYMetadataVersion,
      isTagsField = tokenMetadata.isTagsField,
      firstFieldWithTags = tokenMetadata.firstFieldWithTags;
  var isOneFile = files.length === 1;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var base = "".concat(baseUrl, "file/");

  var getNextData = function getNextData(file) {
    var tags = (0, _utils.getTags)(isOneFile, file, properties.tags, personalTags);
    return isEDGYMetadataVersion && isTagsField ? {
      properties: _objectSpread(_objectSpread({}, properties), {}, _defineProperty({}, firstFieldWithTags.key, firstFieldWithTags.regional_variants && !!firstFieldWithTags.regional_variants.length ? _defineProperty({}, firstFieldWithTags.regional_variants[0], tags) : tags))
    } : {
      properties: _objectSpread(_objectSpread({}, properties), {}, {
        tags: tags
      })
    };
  };

  return sendAll(files.map(function (file) {
    return send("".concat(base).concat(file.uuid, "/properties"), 'PUT', getNextData(file), _defineProperty({}, getSecretHeaderName(platform), uploadKey));
  })).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.saveMetaData = saveMetaData;

var updateProduct = function updateProduct(id, product, _ref6) {
  var container = _ref6.container,
      baseAPI = _ref6.baseAPI,
      platform = _ref6.platform,
      uploadKey = _ref6.uploadKey;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var data = {
    product: product
  };
  return send("".concat(baseUrl, "file/").concat(id, "/product"), 'PUT', data, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.updateProduct = updateProduct;

var getTokenSettings = function getTokenSettings(_ref7) {
  var _ref7$container = _ref7.container,
      container = _ref7$container === void 0 ? '' : _ref7$container,
      baseAPI = _ref7.baseAPI,
      platform = _ref7.platform,
      uploadKey = _ref7.uploadKey;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  return send([baseUrl, 'settings'].join(''), 'GET', null, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var _ref8 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref8$settings = _ref8.settings,
        settings = _ref8$settings === void 0 ? {} : _ref8$settings;

    return {
      productsEnabled: settings._products_enabled === 1
    };
  });
};

exports.getTokenSettings = getTokenSettings;

var getTokenData = function getTokenData(_ref9) {
  var _ref9$container = _ref9.container,
      container = _ref9$container === void 0 ? '' : _ref9$container,
      baseAPI = _ref9.baseAPI,
      platform = _ref9.platform,
      uploadKey = _ref9.uploadKey;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  return send([baseUrl, 'settings'].join(''), 'GET', null, _defineProperty({}, getSecretHeaderName(platform), uploadKey)).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.getTokenData = getTokenData;

var deleteImage = function deleteImage(_ref10) {
  var uuids = _ref10.uuids,
      baseAPI = _ref10.baseAPI,
      _ref10$container = _ref10.container,
      container = _ref10$container === void 0 ? '' : _ref10$container,
      platform = _ref10.platform,
      fileUuid = _ref10.fileUuid,
      dir = _ref10.dir,
      uploadKey = _ref10.uploadKey;
  var baseUrl = getBaseAPI(baseAPI, container, platform);
  var apiPath = uuids.map(function (uuid) {
    return "file/".concat(uuid);
  });
  var urls = apiPath.map(function (path) {
    return [baseUrl, path].join('');
  });
  return sendAll(urls.map(function (url) {
    return send(url, 'DELETE', null, _defineProperty({}, getSecretHeaderName(platform), uploadKey));
  })).then(function () {
    var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return response;
  });
};

exports.deleteImage = deleteImage;
;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(getBaseAPI, "getBaseAPI", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(getBaseUrl, "getBaseUrl", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(getSecretHeaderName, "getSecretHeaderName", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(send, "send", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(sendAll, "sendAll", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(uploadFiles, "uploadFiles", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(getListFiles, "getListFiles", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(searchFiles, "searchFiles", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(generateTags, "generateTags", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(generateMultiplyImagesTags, "generateMultiplyImagesTags", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(saveMetaData, "saveMetaData", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(updateProduct, "updateProduct", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(getTokenSettings, "getTokenSettings", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(getTokenData, "getTokenData", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");

  __REACT_HOT_LOADER__.register(deleteImage, "deleteImage", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\api.service.js");
}();

;