"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sendSelectionData = exports.setAsNotRelevant = exports.addTag = exports.searchIcons = exports.getTags = void 0;

var _axios = _interopRequireDefault(require("axios"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var api_endpoint = 'https://www.openpix.net/v3/icons';

var _send = function _send(url) {
  var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'GET';
  var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var headers = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var responseType = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : "json";
  return new Promise(function (resolve, reject) {
    (0, _axios.default)({
      url: url,
      method: method,
      data: data,
      responseType: responseType,
      headers: headers,
      timeout: 30000
    }).then(function (response) {
      var _response$data = response.data,
          data = _response$data === void 0 ? {} : _response$data;
      var _data$status = data.status,
          status = _data$status === void 0 ? 'error' : _data$status;

      if (status === 'success') {
        resolve(data); // store in cache

        if (method.toLowerCase() === 'get') sessionStorage.setItem(url, JSON.stringify(data));
      } else reject(response);
    }, function (_ref) {
      var _ref$data = _ref.data,
          data = _ref$data === void 0 ? {} : _ref$data;
      reject(data);
    });
  });
};

var getTags = function getTags() {
  return _send("".concat(api_endpoint, "tags")).then(function (_ref2) {
    var _ref2$tags = _ref2.tags,
        tags = _ref2$tags === void 0 ? [] : _ref2$tags;
    return tags;
  });
};

exports.getTags = getTags;

var searchIcons = function searchIcons(searchParams) {
  var relevantActiveTags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var typeQuery = searchParams.typeQuery,
      offset = searchParams.offset,
      openpixKey = searchParams.openpixKey;
  var splittedString = searchParams.value.trim().split(' ');
  var value = "&q[]=".concat(splittedString.map(function (string) {
    return string.trim();
  }).join('&q[]='));
  var tags = relevantActiveTags.map(function (tag) {
    return "&q[]=".concat(tag);
  }).join('');
  var key = "&key=".concat(openpixKey);
  var limitQuery = "&limit=250";
  var offsetQuery = "&offset=".concat(offset);
  return _send("".concat(api_endpoint, "?").concat(value).concat(tags).concat(typeQuery).concat(limitQuery).concat(offsetQuery).concat(key)).then(function (_ref3) {
    var _ref3$icons = _ref3.icons,
        icons = _ref3$icons === void 0 ? [] : _ref3$icons,
        _ref3$count = _ref3.count,
        count = _ref3$count === void 0 ? 0 : _ref3$count,
        related_tags = _ref3.related_tags;
    return {
      icons: icons || [],
      count: count,
      related_tags: related_tags
    };
  });
};

exports.searchIcons = searchIcons;

var addTag = function addTag(uid, tagName) {
  return _send("".concat(api_endpoint, "retag?uid=").concat(uid, "&op=ADD&tag=").concat(tagName));
};

exports.addTag = addTag;

var setAsNotRelevant = function setAsNotRelevant(searchParams) {
  var relevantActiveTags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var uid = arguments.length > 2 ? arguments[2] : undefined;
  var splittedString = searchParams.value.trim().split(' ');
  var value = "&q[]=".concat(splittedString.map(function (string) {
    return string.trim();
  }).join('&q[]='));
  var tags = relevantActiveTags.map(function (tag) {
    return "&q[]=".concat(tag);
  }).join('');
  return _send("".concat(api_endpoint, "improve/relevancy?").concat(value).concat(tags, "&uid=").concat(uid));
};

exports.setAsNotRelevant = setAsNotRelevant;

var sendSelectionData = function sendSelectionData(searchParams) {
  var relevantActiveTags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var uid = arguments.length > 2 ? arguments[2] : undefined;
  var shownIcons = arguments.length > 3 ? arguments[3] : undefined;
  var splittedString = searchParams.value.trim().split(' ');
  var value = "q[]=".concat(splittedString.map(function (string) {
    return string.trim();
  }).join('&q[]='));
  var tags = relevantActiveTags.map(function (tag) {
    return "&q[]=".concat(tag);
  }).join('');
  var data = "".concat(value).concat(tags, "&chosen_uid=").concat(uid, "&shown_icons_uid[]=").concat(shownIcons.map(function (icon) {
    return icon.uid;
  }).join('&shown_icons_uid[]='));
  return _send("".concat(api_endpoint, "improve/selection"), 'POST', data, {}, 'application/x-www-form-urlencoded');
};

exports.sendSelectionData = sendSelectionData;
;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(api_endpoint, "api_endpoint", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(_send, "_send", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(getTags, "getTags", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(searchIcons, "searchIcons", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(addTag, "addTag", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(setAsNotRelevant, "setAsNotRelevant", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");

  __REACT_HOT_LOADER__.register(sendSelectionData, "sendSelectionData", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\iconsApi.service.js");
}();

;