"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getImagesTags = exports.searchImages = exports.getBackgrounds = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _api = require("./api.service");

var _adjustAPI = require("../utils/adjustAPI.utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var api_endpoint = 'https://www.openpix.net/v3/';
var backgroundsAPI = "".concat((0, _api.getBaseUrl)('jolipage-public-assets'), "list?dir=/Backgrounds/v1");

var _send = function _send(url) {
  var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'GET';
  var data = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var headers = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var responseType = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : "json";
  return new Promise(function (resolve, reject) {
    (0, _axios.default)({
      url: url,
      method: method,
      data: data,
      responseType: responseType,
      headers: headers,
      timeout: 30000
    }).then(function (response) {
      var _response$data = response.data,
          data = _response$data === void 0 ? {} : _response$data;
      var _data$status = data.status,
          status = _data$status === void 0 ? 'error' : _data$status;

      if (status === 'success') {
        resolve(data); // store in cache

        if (method.toLowerCase() === 'get') sessionStorage.setItem(url, JSON.stringify(data));
      } else reject(response);
    }, function (_ref) {
      var _ref$data = _ref.data,
          data = _ref$data === void 0 ? {} : _ref$data;
      reject(data);
    });
  });
};

var getBackgrounds = function getBackgrounds() {
  return (0, _api.send)("".concat(backgroundsAPI)).then(function (_ref2) {
    var _ref2$files = _ref2.files,
        files = _ref2$files === void 0 ? [] : _ref2$files;
    return files.map(function () {
      var file = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return {
        src: (0, _adjustAPI.getPubliclink)(file) || (0, _adjustAPI.getPermalink)(file),
        id: file.uuid,
        name: file.name,
        alt: ''
      };
    });
  });
};

exports.getBackgrounds = getBackgrounds;

var searchImages = function searchImages(searchParams) {
  var relevantActiveTags = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var colorFiltersQuery = searchParams.colorFiltersQuery,
      limit = searchParams.limit,
      offset = searchParams.offset,
      openpixKey = searchParams.openpixKey;
  var splittedString = searchParams.value.trim().split(' ');
  var value = searchParams.value ? "&q[]=".concat(splittedString.map(function (string) {
    return string.trim();
  }).join('&q[]=')) : '';
  var tags = relevantActiveTags.map(function (tag) {
    return "&q[]=".concat(tag);
  }).join('');
  var limitQuery = "&limit=".concat(limit);
  var offsetQuery = "&offset=".concat(offset);
  var key = "&key=".concat(openpixKey);
  return _send("".concat(api_endpoint, "search?").concat(value).concat(tags).concat(colorFiltersQuery).concat(limitQuery).concat(offsetQuery).concat(key)).then(function (_ref3) {
    var _ref3$related_tags = _ref3.related_tags,
        related_tags = _ref3$related_tags === void 0 ? [] : _ref3$related_tags,
        _ref3$related_top_col = _ref3.related_top_colors,
        related_top_colors = _ref3$related_top_col === void 0 ? [] : _ref3$related_top_col,
        _ref3$images = _ref3.images,
        images = _ref3$images === void 0 ? [] : _ref3$images,
        _ref3$count = _ref3.count,
        count = _ref3$count === void 0 ? 0 : _ref3$count;
    return {
      images: images,
      count: count,
      related_tags: related_tags,
      related_top_colors: related_top_colors
    };
  });
};

exports.searchImages = searchImages;

var getImagesTags = function getImagesTags() {
  return _send("".concat(api_endpoint, "pictures/tags")).then(function (_ref4) {
    var tags = _ref4.tags;
    return tags;
  });
};

exports.getImagesTags = getImagesTags;
;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(api_endpoint, "api_endpoint", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");

  __REACT_HOT_LOADER__.register(backgroundsAPI, "backgroundsAPI", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");

  __REACT_HOT_LOADER__.register(_send, "_send", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");

  __REACT_HOT_LOADER__.register(getBackgrounds, "getBackgrounds", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");

  __REACT_HOT_LOADER__.register(searchImages, "searchImages", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");

  __REACT_HOT_LOADER__.register(getImagesTags, "getImagesTags", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\services\\imagesApi.service.js");
}();

;