"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.uploadFormDataFiles = void 0;

var _api = require("../services/api.service");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var POST_MAX_FILESIZE_MB = 450;
var POST_MAX_REQUEST_MULTI_FILES_SIZE_MB = 10;
var MAX_FILES_COUNT_PER_REQUEST = 10;
/**
 * https://docs.airstore.io/go/airstore-public-documentation/en/airstore-api-reference/upload-files#od_fae16fa2
 */

var uploadFormDataFiles = function uploadFormDataFiles(formData, url, onUploadProgress) {
  var requestOptions = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

  // Handle the most slow request
  function handleUploadProgress(id) {
    return function (progress) {
      requestsProgressPercent[id] = _objectSpread(_objectSpread({}, requestsProgressPercent[id] || {}), {}, {
        loaded: progress.loaded,
        total: progress.total,
        progress: progress.loaded / progress.total
      });
      var requestsProgressPercentArray = Object.keys(requestsProgressPercent).map(function (propName) {
        return requestsProgressPercent[propName] || {};
      });
      var mostSlowRequest = requestsProgressPercentArray[0];
      requestsProgressPercentArray.forEach(function (item) {
        if (item.progress < mostSlowRequest.progress) {
          mostSlowRequest = item;
        }
      });
      onUploadProgress(mostSlowRequest);
    };
  }

  var requestsProgressPercent = {};
  var putFiles = [];
  var postFiles = [];
  var postFilesChunks = []; // chunk size limit === POST_MAX_FILESIZE_MB

  _toConsumableArray(formData.getAll('files[]')).forEach(function (file) {
    return (bytesToMb(file.size) <= POST_MAX_FILESIZE_MB ? postFiles : putFiles).push(file);
  }); // Sort from small to large, for better chunking


  postFiles.sort(function (a, b) {
    return a.size === b.size ? 0 : a.size < b.size ? -1 : 1;
  }); // Chunking post files

  while (postFiles.length > 0) {
    /**
     * In chunk can be one file (for ex. 200MB) or max 10 files with total size <= 10MB
     */
    var chunk = [postFiles.pop()];
    var i = postFiles.length;

    if (bytesToMb(filesTotalBytesSize(chunk)) < POST_MAX_REQUEST_MULTI_FILES_SIZE_MB) {
      while (i--) {
        if (bytesToMb(filesTotalBytesSize(chunk) + postFiles[i].size) <= POST_MAX_REQUEST_MULTI_FILES_SIZE_MB) {
          chunk.push(postFiles.splice(i, 1)[0]);

          if (chunk.length === MAX_FILES_COUNT_PER_REQUEST) {
            break;
          }
        }
      }
    }

    postFilesChunks.push(chunk);
  }

  var promises = [].concat(_toConsumableArray(putFiles.map(function (file, index) {
    return (0, _api.send)("".concat(url).concat(/\?/.test(url) ? '&' : '?', "filename=").concat(file.name), 'PUT', file, {}, 'json', _objectSpread(_objectSpread({}, requestOptions), {}, {
      onUploadProgress: handleUploadProgress("put-".concat(index)),
      headers: _objectSpread({
        'Content-Type': isJson ? 'application/json' : 'multipart/form-data'
      }, (requestOptions || {}).headers || {})
    }));
  })), _toConsumableArray(postFilesChunks.map(function (chunk, index) {
    var postChunkFormData = new FormData();
    chunk.forEach(function (file) {
      return postChunkFormData.append("files[]", file);
    });
    return (0, _api.send)(url, 'POST', postChunkFormData, {}, 'json', _objectSpread(_objectSpread({}, requestOptions), {}, {
      onUploadProgress: handleUploadProgress("post-chunk-".concat(index)),
      headers: _objectSpread({
        'Content-Type': 'multipart/form-data'
      }, (requestOptions || {}).headers || {})
    }));
  })));
  return Promise.all(promises);
};
/**
 * @param {number} bytes
 */


exports.uploadFormDataFiles = uploadFormDataFiles;

function bytesToMb(bytes) {
  return bytes / 1000000;
}
/**
 * @param {File[]} fileList
 */


function filesTotalBytesSize() {
  var fileList = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return fileList.map(function (file) {
    return file.size;
  }).reduce(function (a, b) {
    return a + b;
  });
}

;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(POST_MAX_FILESIZE_MB, "POST_MAX_FILESIZE_MB", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");

  __REACT_HOT_LOADER__.register(POST_MAX_REQUEST_MULTI_FILES_SIZE_MB, "POST_MAX_REQUEST_MULTI_FILES_SIZE_MB", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");

  __REACT_HOT_LOADER__.register(MAX_FILES_COUNT_PER_REQUEST, "MAX_FILES_COUNT_PER_REQUEST", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");

  __REACT_HOT_LOADER__.register(uploadFormDataFiles, "uploadFormDataFiles", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");

  __REACT_HOT_LOADER__.register(bytesToMb, "bytesToMb", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");

  __REACT_HOT_LOADER__.register(filesTotalBytesSize, "filesTotalBytesSize", "D:\\Work\\Projects\\filerobot-uploader\\projects\\react-plugin\\utils\\files-upload.js");
}();

;